pub struct DisplayHandle<'a> { /* private fields */ }Expand description
The handle to the display controller of the windowing system.
This is the primary return type of the HasDisplayHandle trait. It is guaranteed to contain
a valid platform-specific display handle for its lifetime.
Implementations
Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn android() -> DisplayHandle<'static>
pub fn android() -> DisplayHandle<'static>
Create an Android-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::android();
do_something(handle);Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn appkit() -> DisplayHandle<'static>
pub fn appkit() -> DisplayHandle<'static>
Create an AppKit-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::appkit();
do_something(handle);Sourceimpl<'a> DisplayHandle<'a>
impl<'a> DisplayHandle<'a>
Sourcepub unsafe fn borrow_raw(raw: RawDisplayHandle) -> DisplayHandle<'a>
pub unsafe fn borrow_raw(raw: RawDisplayHandle) -> DisplayHandle<'a>
Create a DisplayHandle from a RawDisplayHandle.
Safety
Users can safely assume that non-null/0 fields are valid handles, and it is up to the
implementer of this trait to ensure that condition is upheld.
Despite that qualification, implementors should still make a best-effort attempt to fill in all available fields. If an implementation doesn’t, and a downstream user needs the field, it should try to derive the field from other fields the implementer does provide via whatever methods the platform provides.
It is not possible to invalidate a DisplayHandle on any platform without additional unsafe code.
Sourcepub fn as_raw(&self) -> RawDisplayHandle
pub fn as_raw(&self) -> RawDisplayHandle
Get the underlying raw display handle.
Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn haiku() -> DisplayHandle<'static>
pub fn haiku() -> DisplayHandle<'static>
Create an Haiku-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::haiku();
do_something(handle);Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn ohos() -> DisplayHandle<'static>
pub fn ohos() -> DisplayHandle<'static>
Create an OpenHarmony-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::ohos();
do_something(handle);Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn orbital() -> DisplayHandle<'static>
pub fn orbital() -> DisplayHandle<'static>
Create an Orbital-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::orbital();
do_something(handle);Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn uikit() -> DisplayHandle<'static>
pub fn uikit() -> DisplayHandle<'static>
Create a UiKit-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::uikit();
do_something(handle);Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn web() -> DisplayHandle<'static>
pub fn web() -> DisplayHandle<'static>
Create a Web-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::web();
do_something(handle);Sourceimpl DisplayHandle<'static>
impl DisplayHandle<'static>
Sourcepub fn windows() -> DisplayHandle<'static>
pub fn windows() -> DisplayHandle<'static>
Create a Windows-based display handle.
As no data is borrowed by this handle, it is completely safe to create. This function may be useful to windowing framework implementations that want to avoid unsafe code.
Example
let handle = DisplayHandle::windows();
do_something(handle);Trait Implementations
Sourceimpl AsRef<RawDisplayHandle> for DisplayHandle<'_>
impl AsRef<RawDisplayHandle> for DisplayHandle<'_>
Sourcefn as_ref(&self) -> &RawDisplayHandle
fn as_ref(&self) -> &RawDisplayHandle
Sourceimpl Borrow<RawDisplayHandle> for DisplayHandle<'_>
impl Borrow<RawDisplayHandle> for DisplayHandle<'_>
Sourcefn borrow(&self) -> &RawDisplayHandle
fn borrow(&self) -> &RawDisplayHandle
Sourceimpl<'a> Clone for DisplayHandle<'a>
impl<'a> Clone for DisplayHandle<'a>
Sourcefn clone(&self) -> DisplayHandle<'a>
fn clone(&self) -> DisplayHandle<'a>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl<'a> Copy for DisplayHandle<'a>
Sourceimpl Debug for DisplayHandle<'_>
impl Debug for DisplayHandle<'_>
impl<'a> Eq for DisplayHandle<'a>
Sourceimpl<'a> HasDisplayHandle for DisplayHandle<'a>
impl<'a> HasDisplayHandle for DisplayHandle<'a>
Sourcefn display_handle(&self) -> Result<DisplayHandle<'_>, HandleError>
fn display_handle(&self) -> Result<DisplayHandle<'_>, HandleError>
Sourceimpl<'a> Hash for DisplayHandle<'a>
impl<'a> Hash for DisplayHandle<'a>
Sourceimpl<'a> PartialEq for DisplayHandle<'a>
impl<'a> PartialEq for DisplayHandle<'a>
Sourcefn eq(&self, other: &DisplayHandle<'a>) -> bool
fn eq(&self, other: &DisplayHandle<'a>) -> bool
self and other values to be equal, and is used by ==.impl<'a> StructuralPartialEq for DisplayHandle<'a>